/*
 * Copyright (c) 2010, 2018 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.api.admin.config;

import java.lang.annotation.*;

/**
 * Defines a binding to a model class, used to retrieve metadata about this
 * model.
 *
 */
@Documented
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
public @interface ModelBinding {
    /**
     * returns the model the annotated type is bound to
     *
     * @return the model type
     */
    public Class<?> type();

    /**
     * Returns the getter method name defined on the {@link org.glassfish.api.admin.config.ModelBinding#type()}
     * type annotated with model information like {@link org.jvnet.hk2.config.Attribute}
     *
     * @return the type getter method name
     */
    public String getterMethodName();
}
